aboutsummaryrefslogtreecommitdiffstats
path: root/lib/bundler/plugin.rb
diff options
context:
space:
mode:
authorAsutosh Palai <asupalai@gmail.com>2016-06-22 09:58:09 +0530
committerAsutosh Palai <asupalai@gmail.com>2016-07-03 09:41:58 +0530
commitd7c0c3fc498c4696d78a07bc350fb2fc4e642b38 (patch)
tree752aef09eb5d388b0f84bc489db033f962fc31d2 /lib/bundler/plugin.rb
parent55b85450f6417610705a5260fdf4bad806528bdf (diff)
downloadbundler-d7c0c3fc498c4696d78a07bc350fb2fc4e642b38.tar.gz
lockfile plugin version shift and inferred_plugin
Diffstat (limited to 'lib/bundler/plugin.rb')
-rw-r--r--lib/bundler/plugin.rb6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/bundler/plugin.rb b/lib/bundler/plugin.rb
index 425f6460..ed77813c 100644
--- a/lib/bundler/plugin.rb
+++ b/lib/bundler/plugin.rb
@@ -51,7 +51,7 @@ module Bundler
plugins = Installer.new.install_definition(definition)
- save_plugins plugins, builder.auto_plugins
+ save_plugins plugins, builder.inferred_plugins
end
# The index object used to store the details about the plugin
@@ -126,8 +126,8 @@ module Bundler
# Post installation processing and registering with index
#
# @param [Hash] plugins mapped to their installtion path
# @param [Array<String>] names of auto added source plugins that can be ignored
def save_plugins(plugins, optional_plugins = [])
plugins.each do |name, path|
path = Pathname.new path
@@ -126,8 +126,8 @@ module Bundler
# Post installation processing and registering with index
#
- # @param [Hash] plugins mapped to their installtion path
- # @param [Array<String>] names of auto added source plugins that can be ignored
+ # @param [Hash] plugins mapped to their installation path
+ # @param [Array<String>] names of inferred source plugins that can be ignored
def save_plugins(plugins, optional_plugins = [])
plugins.each do |name, path|